;; wii-3d-cover.scm -*-scheme-*-
;; Create a 3D cover with transparancy for usb loader gx
;; http://wii2.fr
;; Version 1.0
;;
;; Copyright wii2.fr
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License
;; as published by the Free Software Foundation; either version 2
;; of the License, or (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (script-fu-wii-3d-cover inImage
                                inLayer
                                inFileName
                                inDestination
                                inSaveName
        )

    (
        let* (
                ; Load picture into variable "layer"
                (layer (car (gimp-file-load-layer 0 inImage inFileName)))
                
                ; Create save file name
                (saveFile (string-append inDestination "/" inSaveName ".png"))
                
                ; copy actual layer to restore after treatment
                (undoLayer (car (gimp-layer-copy inLayer 1)))
            )
        
        ; Create an "Undo" group
        (gimp-image-undo-group-start inImage)
        
        ; Release selection
        (gimp-selection-none inImage)
        
        ; Add layer to current image
        (gimp-image-add-layer inImage layer -1)
        
        ; Change perspective to create 3D illusion
        (gimp-drawable-transform-perspective layer 16 6 163 15 16 233 163 219 0 2 TRUE 3 0)
        
        ; Set layer under the disk custom label
        (gimp-image-lower-layer-to-bottom inImage layer)
        
        ; Merge layers
        (gimp-image-merge-visible-layers inImage 1)
        
        ; Get active layer
        (set! layer (car (gimp-image-get-active-layer inImage)))
        
        ; Save PNG
    	(file-png-save 1 inImage layer saveFile saveFile 0 0 0 0 0 1 1)
    	
    	; Remove treated layer
    	(gimp-image-remove-layer inImage layer)
    	
    	; Add original layer
        (gimp-image-add-layer inImage undoLayer -1)
        
        ; Refresh display
    	(gimp-displays-flush)
    	
        ; Close the "Undo" group
        (gimp-image-undo-group-end inImage)
    )
)


(script-fu-register 
    "script-fu-wii-3d-cover"
    "3D cover"
    "Create a 3D cover for USB Loader Gx (and others)"
    "Chpoun's"
    "Pas Glop !"
    "2009/06/14"
    ""
    SF-IMAGE    "Image" 0
    SF-DRAWABLE "Drawable" 0
    SF-FILENAME "Image" "/"
    SF-DIRNAME  "Save directory" ""
    SF-STRING   "Save file (without extension)" ""
)

(script-fu-menu-register "script-fu-wii-3d-cover" "<Image>/Filters/Wii")